@@ -1,6 +1,6 @@
 package P9Y::ProcessTable::Process;
 
-our $VERSION = '0.92'; # VERSION
+our $VERSION = '0.93'; # VERSION
 # ABSTRACT: Base class for a single process
 
 #############################################################################
@@ -31,7 +31,7 @@ has euid     => ( is => 'rwp', predicate => 1 );
 has egid     => ( is => 'rwp', predicate => 1 );
 has suid     => ( is => 'rwp', predicate => 1 );
 has sgid     => ( is => 'rwp', predicate => 1 );
-has ppid     => ( is => 'rwp', required  => 1 );
+has ppid     => ( is => 'rwp', predicate => 1 );
 has pgrp     => ( is => 'rwp', predicate => 1 );
 has sess     => ( is => 'rwp', predicate => 1 );
 
@@ -163,8 +163,7 @@ Unlike the other data methods (below), these two are settable by passing a value
 
 =head2 Process data methods
 
-Depending on the OS, the following methods are available.  Also, all methods also have a C<<< has_* >>> predicate, except for C<<< pid >>> and C<<< ppid >>> which 
-are required (ie: exists on all OSs).
+Depending on the OS, the following methods are available.  Also, all methods also have a C<<< has_* >>> predicate, except for C<<< pid >>>.
 
     pid       Process ID
     uid       UID of process
@@ -211,8 +210,8 @@ are required (ie: exists on all OSs).
     pctcpu    Percent CPU used
     pctmem    Percent memory used
 
-Make no assumptions about what is available and what is not, besides maybe C<<< pid >>> & C<<< ppid >>>.  Instead, use the C<<< has_* >>> methods and plan for
-alternatives if that data isn't available.
+Make no assumptions about what is available and what is not, not even C<<< ppid >>>.  Instead, use the C<<< has_* >>> methods and plan for alternatives
+if that data isn't available.
 
 =head1 CAVEATS
 
